import Image, ImageDraw, ImageFilter
import math, random

side = 64

def drawFirstLine(draw, pos, square):
	global side

	edge = side/4.5
	y = (pos-1)*side

	line = 0
	limit = y+edge
	while (y < limit):
		diff = (edge-line)/edge
		diff = math.degrees(math.asin(diff)) / 90.0
		diff = diff*edge
		draw.line((side*square[0]+diff, y, side*square[1]-diff, y), fill=(256,256,256,256))
		line += 1
		y += 1
	
	while (y < pos*side):
		draw.line((square[0]*side, y, square[1]*side,y), fill=(256,256,256,256))
		y += 1

	drawClouds(draw, (square[0]*side,(pos-1)*side ,square[1]*side,pos*side));

def drawClouds(draw, limits):
	num_clouds = 6 * limits[2] - limits[0];
	for i in range(num_clouds):
		x = random.randint(limits[0]+1, limits[2]);
		y = random.randint(limits[1], limits[3]);
		radius = random.randint(0,30);
		draw.ellipse((x-radius,y-radius,x+radius,y+radius), fill=(256,256,256,256))


def drawLastLine(draw, pos, square):
	edge = side/5.0
	y = (pos-1)*side

	while(y < (pos*side)-edge):
		draw.line((square[0]*side, y, square[1]*side,y), fill=(256,256,256,256))
		y += 1

	while( y < pos*side):
		diff = (edge - ((pos*side) - y))/edge
		diff = math.degrees(math.asin(diff)) / 90.0
		diff = diff*edge
		draw.line((side*square[0]+diff, y, side*square[1]-diff, y), fill=(256,256,256,256))
		y += 1

	drawClouds(draw, (square[0]*side,(pos-1)*side ,square[1]*side,pos*side));


def clearLine(draw, pos, square):
	global side
	y = (pos-1)*side

	while(y < pos*side):
		draw.line((square[0]*side, y, square[1]*side,y), fill=(0,0,0,0))
		y += 1


def drawLine(draw, pos, square):
	global side
	y = (pos-1)*side

	while(y < pos*side):
		draw.line((square[0]*side, y, square[1]*side,y), fill=(256,256,256,256))
		y += 1

	drawClouds(draw, (square[0]*side,(pos-1)*side ,square[1]*side,pos*side));


if __name__ == "__main__":
	import sys

	if len(sys.argv) != 2:
		sys.exit()

	f = open(sys.argv[1])
	lines = f.readlines()

	# Read target map size
	width, height = [int(n) for n in lines[0].split()]

	im = Image.new("RGBA",(width*side, height*side),(0,0,0,0))
	draw = ImageDraw.Draw(im)

	# Stuff to keep track on cycle
	i=1
	lastSquares = []
	squares = []

	while i <= height:
		lastFilled = False
		start = -1
		end = -1
		for j in range(width):
			if(lines[i][j] == "#"):
				if(not lastFilled):
					start = j
				lastFilled = True
			elif(lines[i][j] == " "):
				if(lastFilled):
					end = j
					squares.append((start,end))
					start=-1
					end=-1
				lastFilled = False

		if start != -1 and end == -1:
			squares.append((start,width))
		#Draw stuff
		for square in squares:
			if square in lastSquares:
				drawLine(draw,i,square)
			else:
				drawFirstLine(draw, i, square)

		for ls in lastSquares:
			if ls not in squares:
				clearLine(draw, i-1, ls)
				drawLastLine(draw, i-1, ls)

		lastSquares = squares
		squares = []

		i += 1
	
	#Apply global filters

	#Save
	im.save(open("test.png","w"), "PNG")

					
					

	
	
